@@ -1,4 +1,4 @@
-# Copyright (C) 1998-2004 by the Free Software Foundation, Inc.
+# Copyright (C) 1998-2005 by the Free Software Foundation, Inc.
 #
 # This program is free software; you can redistribute it and/or
 # modify it under the terms of the GNU General Public License
@@ -12,10 +12,10 @@
 #
 # You should have received a copy of the GNU General Public License
 # along with this program; if not, write to the Free Software
-# Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301,
+# USA.
 
-"""Handle delivery bounces.
-"""
+"""Handle delivery bounces."""
 
 import sys
 import time
@@ -145,14 +145,14 @@ class Bouncer:
                 info.score += weight
                 info.date = day
                 syslog('bounce', '%s: %s current bounce score: %s',
-                       member, self.internal_name(), info.score)
+                       self.internal_name(), member, info.score)
             # Continue to the check phase below
         #
         # Now that we've adjusted the bounce score for this bounce, let's
         # check to see if the disable-by-bounce threshold has been reached.
         if info.score >= self.bounce_score_threshold:
             if mm_cfg.VERP_PROBES:
-                syslog('bounce', 
+                syslog('bounce',
                    'sending %s list probe to: %s (score %s >= %s)',
                    self.internal_name(), member, info.score,
                    self.bounce_score_threshold)
