@@ -1,4 +1,4 @@
-# Copyright (C) 2001-2005 by the Free Software Foundation, Inc.
+# Copyright (C) 2001-2006 by the Free Software Foundation, Inc.
 #
 # This program is free software; you can redistribute it and/or
 # modify it under the terms of the GNU General Public License
@@ -12,7 +12,8 @@
 #
 # You should have received a copy of the GNU General Public License
 # along with this program; if not, write to the Free Software
-# Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301,
+# USA.
 
 """Cleanse a message for archiving."""
 
@@ -110,10 +111,10 @@ class ScrubberGenerator(Generator):
             Generator._write_headers(self, msg)
 
 
-def safe_strftime(fmt, floatsecs):
+def safe_strftime(fmt, t):
     try:
-        return time.strftime(fmt, floatsecs)
-    except (TypeError, ValueError):
+        return time.strftime(fmt, t)
+    except (TypeError, ValueError, OverflowError):
         return None
 
 
@@ -161,6 +162,14 @@ def calculate_attachments_dir(mlist, msg, msgdata):
     return os.path.join('attachments', datedir, digest[:4] + digest[-4:])
 
 
+def replace_payload_by_text(msg, text, charset):
+    # TK: This is a common function in replacing the attachment and the main
+    # message by a text (scrubbing).
+    del msg['content-type']
+    del msg['content-transfer-encoding']
+    msg.set_payload(text, charset)
+
+
 
 def process(mlist, msg, msgdata=None):
     sanitize = mm_cfg.ARCHIVE_HTML_SANITIZER
@@ -197,9 +206,7 @@ def process(mlist, msg, msgdata=None):
                     os.umask(omask)
                 filename = part.get_filename(_('not available'))
                 filename = Utils.oneline(filename, lcset)
-                del part['content-type']
-                del part['content-transfer-encoding']
-                part.set_payload(_("""\
+                replace_payload_by_text(part, _("""\
 An embedded and charset-unspecified text was scrubbed...
 Name: %(filename)s
 Url: %(url)s
@@ -208,10 +215,9 @@ Url: %(url)s
             if sanitize == 0:
                 if outer:
                     raise DiscardMessage
-                del part['content-type']
-                del part['content-transfer-encoding']
-                part.set_payload(_('HTML attachment scrubbed and removed'),
-                                 # Adding charset arg and removing content-tpe
+                replace_payload_by_text(part,
+                                 _('HTML attachment scrubbed and removed'),
+                                 # Adding charset arg and removing content-type
                                  # sets content-type to text/plain
                                  lcset)
             elif sanitize == 2:
@@ -226,9 +232,7 @@ Url: %(url)s
                     url = save_attachment(mlist, part, dir, filter_html=False)
                 finally:
                     os.umask(omask)
-                del part['content-type']
-                del part['content-transfer-encoding']
-                part.set_payload(_("""\
+                replace_payload_by_text(part, _("""\
 An HTML attachment was scrubbed...
 URL: %(url)s
 """), lcset)
@@ -253,8 +257,7 @@ URL: %(url)s
                     url = save_attachment(mlist, part, dir, filter_html=False)
                 finally:
                     os.umask(omask)
-                del part['content-type']
-                part.set_payload(_("""\
+                replace_payload_by_text(part, _("""\
 An HTML attachment was scrubbed...
 URL: %(url)s
 """), lcset)
@@ -270,8 +273,7 @@ URL: %(url)s
             date = submsg.get('date', _('no date'))
             who = submsg.get('from', _('unknown sender'))
             size = len(str(submsg))
-            del part['content-type']
-            part.set_payload(_("""\
+            replace_payload_by_text(part, _("""\
 An embedded message was scrubbed...
 From: %(who)s
 Subject: %(subject)s
@@ -302,9 +304,7 @@ Url: %(url)s
             desc = part.get('content-description', _('not available'))
             filename = part.get_filename(_('not available'))
             filename = Utils.oneline(filename, lcset)
-            del part['content-type']
-            del part['content-transfer-encoding']
-            part.set_payload(_("""\
+            replace_payload_by_text(part, _("""\
 A non-text attachment was scrubbed...
 Name: %(filename)s
 Type: %(ctype)s
@@ -343,7 +343,12 @@ Url : %(url)s
                 continue
             try:
                 t = part.get_payload(decode=True)
-            except binascii.Error:
+            # MAS: TypeError exception can occur if payload is None. This
+            # was observed with a message that contained an attached
+            # message/delivery-status part. Because of the special parsing
+            # of this type, this resulted in a text/plain sub-part with a
+            # null body. See bug 1430236.
+            except (binascii.Error, TypeError):
                 t = part.get_payload()
             # TK: get_content_charset() returns 'iso-2022-jp' for internally
             # crafted (scrubbed) 'euc-jp' text part. So, first try
@@ -375,10 +380,7 @@ Url : %(url)s
                 text.append(t)
         # Now join the text and set the payload
         sep = _('-------------- next part --------------\n')
-        del msg['content-type']
-        msg.set_payload(sep.join(text), charset)
-        del msg['content-transfer-encoding']
-        msg.add_header('Content-Transfer-Encoding', '8bit')
+        replace_payload_by_text(msg, sep.join(text), charset)
     return msg
 
 
@@ -509,5 +511,7 @@ def save_attachment(mlist, msg, dir, filter_html=True):
     # Private archives will likely have a trailing slash.  Normalize.
     if baseurl[-1] <> '/':
         baseurl += '/'
-    url = baseurl + '%s/%s%s%s' % (dir, filebase, extra, ext)
+    # A trailing space in url string may save users who are using
+    # RFC-1738 compliant MUA (Not Mozilla).
+    url = baseurl + '%s/%s%s%s ' % (dir, filebase, extra, ext)
     return url
