@@ -1336,6 +1336,7 @@ LC_DESCRIPTIONS = {}
 def add_language(code, description, charset):
     LC_DESCRIPTIONS[code] = (description, charset)
 
+add_language('ar',    _('Arabic'),              'utf-8')
 add_language('ca',    _('Catalan'),             'iso-8859-1')
 add_language('cs',    _('Czech'),               'iso-8859-2')
 add_language('da',    _('Danish'),              'iso-8859-1')
@@ -1365,6 +1366,7 @@ add_language('sl',    _('Slovenian'),           'iso-8859-2')
 add_language('sv',    _('Swedish'),             'iso-8859-1')
 add_language('tr',    _('Turkish'),             'iso-8859-9')
 add_language('uk',    _('Ukrainian'),           'utf-8')
+add_language('vi',    _('Vietnamese'),          'utf-8')
 add_language('zh_CN', _('Chinese (China)'),     'utf-8')
 add_language('zh_TW', _('Chinese (Taiwan)'),    'utf-8')
 
