@@ -1,4 +1,4 @@
-# Copyright (C) 1998-2005 by the Free Software Foundation, Inc.
+# Copyright (C) 1998-2006 by the Free Software Foundation, Inc.
 #
 # This program is free software; you can redistribute it and/or
 # modify it under the terms of the GNU General Public License
@@ -12,7 +12,8 @@
 #
 # You should have received a copy of the GNU General Public License
 # along with this program; if not, write to the Free Software
-# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
+# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301,
+# USA.
 
 
 """Miscellaneous essential routines.
@@ -52,6 +53,7 @@ from Mailman import mm_cfg
 from Mailman import Errors
 from Mailman import Site
 from Mailman.SafeDict import SafeDict
+from Mailman.Logging.Syslog import syslog
 
 try:
     True, False
@@ -203,7 +205,7 @@ def LCDomain(addr):
 _badchars = re.compile(r'[][()<>|;^,\000-\037\177-\377]')
 
 def ValidateEmail(s):
-    """Verify that the an email address isn't grossly evil."""
+    """Verify that an email address isn't grossly evil."""
     # Pretty minimal, cheesy check.  We could do better...
     if not s or s.count(' ') > 0:
         raise Errors.MMBadEmailError
@@ -218,9 +220,16 @@ def ValidateEmail(s):
 
 
 
+# Patterns which may be used to form malicious path to inject a new
+# line in the mailman error log. (TK: advisory by Moritz Naumann)
+CRNLpat = re.compile(r'[^\x21-\x7e]')
+
 def GetPathPieces(envar='PATH_INFO'):
     path = os.environ.get(envar)
     if path:
+        if CRNLpat.search(path):
+            path = CRNLpat.split(path)[0]
+            syslog('error', 'Warning: Possible malformed path attack.')
         return [p for p in path.split('/') if p]
     return None
 
@@ -325,7 +334,6 @@ def Secure_MakeRandomPassword(length):
                         # We have no available source of cryptographically
                         # secure random characters.  Log an error and fallback
                         # to the user friendly passwords.
-                        from Mailman.Logging.Syslog import syslog
                         syslog('error',
                                'urandom not available, passwords not secure')
                         return UserFriendly_MakeRandomPassword(length)
@@ -435,6 +443,9 @@ def UnobscureEmail(addr):
 
 
 
+class OuterExit(Exception):
+    pass
+
 def findtext(templatefile, dict=None, raw=False, lang=None, mlist=None):
     # Make some text from a template file.  The order of searches depends on
     # whether mlist and lang are provided.  Once the templatefile is found,
@@ -501,7 +512,6 @@ def findtext(templatefile, dict=None, raw=False, lang=None, mlist=None):
     searchdirs.append(os.path.join(mm_cfg.TEMPLATE_DIR, 'site'))
     searchdirs.append(mm_cfg.TEMPLATE_DIR)
     # Start scanning
-    quickexit = 'quickexit'
     fp = None
     try:
         for lang in languages:
@@ -509,12 +519,12 @@ def findtext(templatefile, dict=None, raw=False, lang=None, mlist=None):
                 filename = os.path.join(dir, lang, templatefile)
                 try:
                     fp = open(filename)
-                    raise quickexit
+                    raise OuterExit
                 except IOError, e:
                     if e.errno <> errno.ENOENT: raise
                     # Okay, it doesn't exist, keep looping
                     fp = None
-    except quickexit:
+    except OuterExit:
         pass
     if fp is None:
         # Try one last time with the distro English template, which, unless
@@ -540,7 +550,6 @@ def findtext(templatefile, dict=None, raw=False, lang=None, mlist=None):
                 text = sdict.interpolate(utemplate)
         except (TypeError, ValueError), e:
             # The template is really screwed up
-            from Mailman.Logging.Syslog import syslog
             syslog('error', 'broken template: %s\n%s', filename, e)
             pass
     if raw:
@@ -679,9 +688,11 @@ def get_domain():
     if mm_cfg.VIRTUAL_HOST_OVERVIEW and host:
         return host.lower()
     else:
-        # See the note in Defaults.py concerning DEFAULT_HOST_NAME
-        # vs. DEFAULT_EMAIL_HOST.
-        hostname = mm_cfg.DEFAULT_HOST_NAME or mm_cfg.DEFAULT_EMAIL_HOST
+        # See the note in Defaults.py concerning DEFAULT_URL
+        # vs. DEFAULT_URL_HOST.
+        hostname = ((mm_cfg.DEFAULT_URL
+                     and urlparse.urlparse(mm_cfg.DEFAULT_URL)[1])
+                     or mm_cfg.DEFAULT_URL_HOST)
         return hostname.lower()
 
 
